summaryrefslogtreecommitdiffstats
path: root/kmail/kmsearchpattern.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmsearchpattern.cpp')
-rw-r--r--kmail/kmsearchpattern.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kmail/kmsearchpattern.cpp b/kmail/kmsearchpattern.cpp
index 4af3d68a0..4c4340a2b 100644
--- a/kmail/kmsearchpattern.cpp
+++ b/kmail/kmsearchpattern.cpp
@@ -33,7 +33,7 @@ using KMail::FilterLog;
#include <assert.h>
static const char* funcConfigNames[] =
- { "tqcontains", "tqcontains-not", "equals", "not-equal", "regexp",
+ { "contains", "contains-not", "equals", "not-equal", "regexp",
"not-regexp", "greater", "less-or-equal", "less", "greater-or-equal",
"is-in-addressbook", "is-not-in-addressbook" , "is-in-category", "is-not-in-category",
"has-attachment", "has-no-attachment"};
@@ -281,10 +281,10 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
rc = ( ( function() & 1 ) == 1 );
else {
start += headerLen;
- size_t stop = aStr.tqfind( '\n', start );
+ size_t stop = aStr.find( '\n', start );
char ch = '\0';
while ( stop != DwString::npos && ( ( ch = aStr.at( stop + 1 ) ) == ' ' || ch == '\t' ) )
- stop = aStr.tqfind( '\n', stop + 1 );
+ stop = aStr.find( '\n', stop + 1 );
const int len = stop == DwString::npos ? aStr.length() - start : stop - start ;
const TQCString codedValue( aStr.data() + start, len + 1 );
const TQString msgContents = KMMsgBase::decodeRFC2047String( codedValue ).stripWhiteSpace(); // FIXME: This needs to be changed for IDN support.
@@ -294,11 +294,11 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
static const DwBoyerMoore to("\nTo: ");
static const DwBoyerMoore cc("\nCc: ");
static const DwBoyerMoore bcc("\nBcc: ");
// <recipients> "tqcontains" "foo" is true if any of the fields tqcontains
// "foo", while <recipients> "does not contain" "foo" is true if none
// of the fields tqcontains "foo"
if ( ( function() & 1 ) == 0 ) {
- // positive function, e.g. "tqcontains"
+ // positive function, e.g. "contains"
rc = ( matches( aStr, msg, &to, 2 ) ||
matches( aStr, msg, &cc, 2 ) ||
matches( aStr, msg, &bcc, 3 ) );
@@ -419,10 +419,10 @@ bool KMSearchRuleString::matchesInternal( const TQString & msgContents ) const
return ( TQString::compare( msgContents.lower(), contents().lower() ) != 0 );
case KMSearchRule::FuncContains:
- return ( msgContents.tqfind( contents(), 0, false ) >= 0 );
+ return ( msgContents.find( contents(), 0, false ) >= 0 );
case KMSearchRule::FuncContainsNot:
- return ( msgContents.tqfind( contents(), 0, false ) < 0 );
+ return ( msgContents.find( contents(), 0, false ) < 0 );
case KMSearchRule::FuncRegExp:
{
@@ -576,10 +576,10 @@ bool KMSearchRuleNumerical::matchesInternal( long numericalValue,
return ( numericalValue != numericalMsgContents );
case KMSearchRule::FuncContains:
- return ( msgContents.tqfind( contents(), 0, false ) >= 0 );
+ return ( msgContents.find( contents(), 0, false ) >= 0 );
case KMSearchRule::FuncContainsNot:
- return ( msgContents.tqfind( contents(), 0, false ) < 0 );
+ return ( msgContents.find( contents(), 0, false ) < 0 );
case KMSearchRule::FuncRegExp:
{
@@ -294,11 +294,11 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
static const DwBoyerMoore cc("\nCc: ");
static const DwBoyerMoore bcc("\nBcc: ");
- // <recipients> "tqcontains" "foo" is true if any of the fields tqcontains
+ // <recipients> "contains" "foo" is true if any of the fields contains
// "foo", while <recipients> "does not contain" "foo" is true if none
@@ -294,11 +294,11 @@ bool KMSearchRuleString::matches( const DwString & aStr, KMMessage & msg,
// "foo", while <recipients> "does not contain" "foo" is true if none
- // of the fields tqcontains "foo"
+ // of the fields contains "foo"
if ( ( function() & 1 ) == 0 ) {